@@ -1,13 +1,13 @@
 import json
-
 import grpc
+from .channel import CHANNEL
 from .gRPC_proto.user import user_pb2, user_pb2_grpc, auth_pb2_grpc, auth_pb2
 
 
 class User:
-    def __init__(self, channel, username, password):
-        self.stub = user_pb2_grpc.UserControllerStub(channel)
-        self.auth_stub = auth_pb2_grpc.AuthenticationStub(channel)
+    def __init__(self, username, password):
+        self.stub = user_pb2_grpc.UserControllerStub(CHANNEL)
+        self.auth_stub = auth_pb2_grpc.AuthenticationStub(CHANNEL)
         self.username = username
         self.password = password
 
@@ -30,7 +30,7 @@ class User:
     def login(self):
         try:
             response = self.auth_stub.Login(auth_pb2.LoginRequest(username=self.username, password=self.password))
-            meta = [('access_token', json.loads(response.token)['token'])]
+            meta = [('jwt-access-token', json.loads(response.token)['token'])]
             return meta
         except grpc.RpcError as e:
             raise Exception('Error ' + str(e.code()) + ': ' + str(e.details()))
